diff --git a/src/components/Container.stories.tsx b/src/components/Container.stories.tsx
index 47b9a09..b223fc8 100644
--- a/src/components/Container.stories.tsx
+++ b/src/components/Container.stories.tsx
@@ -1,7 +1,6 @@
 import React from 'react';
 
 import { ComponentMeta, ComponentStory } from '@storybook/react';
-import { INITIAL_VIEWPORTS } from '@storybook/addon-viewport';
 
 import Container from './Container';
 
@@ -24,7 +23,7 @@ export default {
  * on a returning component.
  */
 const Template: ComponentStory<typeof Container> = (args) => (
-  <Container {...args}><div className='w-40 h-40 bg-yellow-400'>simple</div></Container>
+  <Container {...args}><div className='h-40 bg-yellow-400 flex items-center justify-center uppercase font-bold'>simple</div></Container>
 );
 //
 /* -------------------------------------------------------------------------- */
diff --git a/src/components/Container.tsx b/src/components/Container.tsx
index c7c432d..9581476 100644
--- a/src/components/Container.tsx
+++ b/src/components/Container.tsx
@@ -1,14 +1,15 @@
 import classNames from "classnames";
+import React from "react";
 type Props = {
   /**
    * Content of compnent
    */
   children: React.ReactNode;
   /**
-   * Compnent styling
+   * Component styling
    */
   className?: string;
-}
+} & Omit<React.ComponentPropsWithoutRef<"div">, "">
 /**
  * Main container to handle page content max-width on
  * different screen sizes
@@ -1,14 +1,15 @@
 type Props = {
   /**
-   * Content of compnent
+   * Content of component
    */
   children: React.ReactNode;